==> chemistry-opencmis-server-inmemory-0.8.0-sources.jar: org/apache/chemistry/opencmis/inmemory/types/TypeDefinitions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.inmemory.types;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.chemistry.opencmis.commons.impl.Constants;
import org.apache.chemistry.opencmis.commons.impl.jaxb.CmisTypeDefinitionType;

@XmlRootElement
public class TypeDefinitions {

    protected List<CmisTypeDefinitionType> type;

    @XmlElement(namespace = Constants.NAMESPACE_RESTATOM, name = "type")
    public List<CmisTypeDefinitionType> getTypeDefinitions() {
        if (type == null) {
            type = new ArrayList<CmisTypeDefinitionType>();
        }
        return this.type;
    }

}

==> chemistry-opencmis-server-inmemory-0.14.0-sources.jar: org/apache/chemistry/opencmis/inmemory/types/TypeDefinitions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.chemistry.opencmis.inmemory.types;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.chemistry.opencmis.commons.impl.XMLConstants;
import org.apache.chemistry.opencmis.commons.impl.jaxb.CmisTypeDefinitionType;

@XmlRootElement
public class TypeDefinitions {

    private List<CmisTypeDefinitionType> type;

    @XmlElement(namespace = XMLConstants.NAMESPACE_RESTATOM, name = "type")
    public List<CmisTypeDefinitionType> getTypeDefinitions() {
        if (type == null) {
            type = new ArrayList<CmisTypeDefinitionType>();
        }
        return this.type;
    }

}
